from bson.objectid import ObjectId


# Retrieve all objs present in the database
async def retrieve(collection, helper):
    objs = []
    async for obj in collection.find():
        objs.append(helper(obj))
    return objs


# Add a new obj into to the database
async def add_obj(data: dict, collection, helper) -> dict:
    try:
        obj = await collection.insert_one(data)
        new_obj = await collection.find_one({"_id": obj.inserted_id})
        return helper(new_obj)
    except Exception as e:
        return {'msg': 'phone or email already exists', 'error': str(e)}


# Retrieve an obj with a matching ID
async def retrieve_obj(id: str, collection, helper) -> dict:
    obj = await collection.find_one({"_id": ObjectId(id)})
    if obj:
        return helper(obj)


# Update an obj with a matching ID
async def update_obj(id: str, data: dict, collection):
    # Return false if an empty request body is sent.
    if len(data) < 1:
        return False
    obj = await collection.find_one({"_id": ObjectId(id)})
    if obj:
        updated_obj = await collection.update_one(
            {"_id": ObjectId(id)}, {"$set": data}
        )
        if updated_obj:
            return True
        return False


# Delete an obj from the database
async def delete_obj(id: str, collection):
    obj = await collection.find_one({"_id": ObjectId(id)})
    if obj:
        await collection.delete_one({"_id": ObjectId(id)})
        return True


# Find Object
async def get_object_by_field(collection, helper, field, data):
    try:
        cursor = collection.find({field: data})
        data = await cursor.to_list(length=10)
        print('---- ', data)
        result = []
        if len(data) > 0:
            for obj in data:
                result.append(helper(obj))
        return result
    except Exception as e:
        print(e)

